==> huaweicloudsdkgaussdbforopengauss-3.1.75-py2.py3-none-any.whl: huaweicloudsdkgaussdbforopengauss/v3/model/download_backup_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DownloadBackupResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'files': 'list[DownloadObject]',
        'bucket': 'str'
    }

    attribute_map = {
        'files': 'files',
        'bucket': 'bucket'
    }

    def __init__(self, files=None, bucket=None):
        """DownloadBackupResponse

        The model defined in huaweicloud sdk

        :param files: 备份文件信息。
        :type files: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.DownloadObject`]
        :param bucket: 桶名。
        :type bucket: str
        """
        
        super(DownloadBackupResponse, self).__init__()

        self._files = None
        self._bucket = None
        self.discriminator = None

        if files is not None:
            self.files = files
        if bucket is not None:
            self.bucket = bucket

    @property
    def files(self):
        """Gets the files of this DownloadBackupResponse.

        备份文件信息。

        :return: The files of this DownloadBackupResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.DownloadObject`]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this DownloadBackupResponse.

        备份文件信息。

        :param files: The files of this DownloadBackupResponse.
        :type files: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.DownloadObject`]
        """
        self._files = files

    @property
    def bucket(self):
        """Gets the bucket of this DownloadBackupResponse.

        桶名。

        :return: The bucket of this DownloadBackupResponse.
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this DownloadBackupResponse.

        桶名。

        :param bucket: The bucket of this DownloadBackupResponse.
        :type bucket: str
        """
        self._bucket = bucket

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DownloadBackupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbforopengauss-3.1.143-py2.py3-none-any.whl: huaweicloudsdkgaussdbforopengauss/v3/model/download_backup_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DownloadBackupResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'files': 'list[DownloadObject]',
        'bucket': 'str'
    }

    attribute_map = {
        'files': 'files',
        'bucket': 'bucket'
    }

    def __init__(self, files=None, bucket=None):
        r"""DownloadBackupResponse

        The model defined in huaweicloud sdk

        :param files: 备份文件信息。
        :type files: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.DownloadObject`]
        :param bucket: 桶名。
        :type bucket: str
        """
        
        super(DownloadBackupResponse, self).__init__()

        self._files = None
        self._bucket = None
        self.discriminator = None

        if files is not None:
            self.files = files
        if bucket is not None:
            self.bucket = bucket

    @property
    def files(self):
        r"""Gets the files of this DownloadBackupResponse.

        备份文件信息。

        :return: The files of this DownloadBackupResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.DownloadObject`]
        """
        return self._files

    @files.setter
    def files(self, files):
        r"""Sets the files of this DownloadBackupResponse.

        备份文件信息。

        :param files: The files of this DownloadBackupResponse.
        :type files: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.DownloadObject`]
        """
        self._files = files

    @property
    def bucket(self):
        r"""Gets the bucket of this DownloadBackupResponse.

        桶名。

        :return: The bucket of this DownloadBackupResponse.
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        r"""Sets the bucket of this DownloadBackupResponse.

        桶名。

        :param bucket: The bucket of this DownloadBackupResponse.
        :type bucket: str
        """
        self._bucket = bucket

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DownloadBackupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
